Documentation
===============

pycodata
----------------------------
.. automodule:: pycodata
    :members:

All attributes of the C extension :obj:`pycodata._codata` are directly 
available in the python wrapper.


_codata
------------------------
.. automodule:: pycodata._codata
    :members:
